@@ -1,6 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Testruns;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Reports::Web::Controller::Tapper::Testruns::VERSION = '5.0.13';
+$Tapper::Reports::Web::Controller::Tapper::Testruns::VERSION = '5.0.14';
 use parent 'Tapper::Reports::Web::Controller::Base';
 use Cwd;
 use Data::DPath 'dpath';
@@ -300,8 +300,7 @@ sub new_create : Chained('base') :PathPart('create') :Args(0) :FormConfig
                 $c->res->redirect('/tapper/testruns/fill_usecase');
 
         } else {
-                my $select = $form->get_element({type => 'Select', name => 'topic'});
-                $select->options($self->get_topic_names());
+                my $select;
 
                 $select = $form->get_element({type => 'Select', name => 'owner'});
                 $select->options($self->get_owner_names());
@@ -314,13 +313,18 @@ sub new_create : Chained('base') :PathPart('create') :Args(0) :FormConfig
                 foreach my $file (glob "$path/*.mpc") {
                         open my $fh, "<", $file or $c->response->body(qq(Can not open $file: $!)), return;
                         my $desc;
+                        my $hide;
                         while (my $line = <$fh>) {
                                 ($desc) = $line =~/^#+ *(?:tapper[_-])?description:\s*(.+)/;
                                 last if $desc;
                         }
+                        while (my $line = <$fh>) {
+                                ($hide) = $line =~/^#+ *(?:tapper[_-])?hide-in-webgui:\s*(.+)/;
+                                last if $hide;
+                        }
 
                         my ($shortfile, undef, undef) = File::Basename::fileparse($file, ('.mpc'));
-                        push @use_cases, [$file, "$shortfile - $desc"];
+                        push @use_cases, [$file, "$shortfile - $desc"] unless $hide;
 
                 }
                 my $select = $form->get_element({type => 'Radiogroup', name => 'use_case'});
@@ -385,7 +389,7 @@ sub parse_macro_precondition :Private
         my ($self, $c, $file) = @_;
         my $config;
         my $home = $c->path_to();
-
+        my ($shortfile, undef, undef) = File::Basename::fileparse($file, ('.mpc'));
 
         open my $fh, "<", $file or return "Can not open use case description $file:$!";
         my ($required, $optional, $mpc_config) = ('', '', '');
@@ -435,6 +439,20 @@ sub parse_macro_precondition :Private
                 }
                 $config->{mpc_config} = $mpc_config;
         }
+
+        # Default field "testrun_topic" in every form
+        if (not grep { $_->{name} eq "testrun_topic" } @{$config->{required}}) {
+            unshift @{$config->{required}},
+            {
+                type => "Text",
+                name => "testrun_topic",
+                label => "Testrun topic",
+                value =>  join("-", "usertest", ($shortfile || ())),
+                constraints => [ { type => 'Required', message_xml => '<span style="color:#B40404">Please fill mandatory field</span>' } ],
+                attributes => { size => 50 },
+            }
+        }
+
         return $config;
 }
 
@@ -515,6 +533,7 @@ sub fill_usecase : Chained('base') :PathPart('fill_usecase') :Args(0) :FormConfi
         my $form       = $c->stash->{form};
         my $position   = $form->get_element({type => 'Submit'});
         my $file       = $c->session->{usecase_file};
+        my ($shortfile, undef, undef) = File::Basename::fileparse($file, ('.mpc'));
         my %macros;
         $c->res->redirect('/tapper/testruns/create') unless $file;
 
@@ -541,10 +560,19 @@ sub fill_usecase : Chained('base') :PathPart('fill_usecase') :Args(0) :FormConfi
         $form->elements({type => 'Submit', name => 'submit', value => 'Submit'});
         $form->process();
 
-
         if ($form->submitted_and_valid) {
                 my $testrun_data = $c->session->{testrun_data};
                 my @testhosts;
+
+                # allow overwrite testrun topic
+                my $testrun_topic = $form->input->{testrun_topic};
+                if ($testrun_topic) {
+                    $testrun_data->{topic} = $testrun_topic;
+                } else {
+                    $testrun_data->{topic} = "undefined-topic";
+                }
+
+                # hosts
                 if ( defined ($testrun_data->{requested_hosts})){
                         if ( ref($testrun_data->{requested_hosts}) eq 'ARRAY') {
                                 @testhosts = @{$testrun_data->{requested_hosts}};
@@ -830,7 +858,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2019 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
